==> _private_chat-1.3.48.tar.gz: lib/utils/utils.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../chat_detail/chat_helper.dart';
import '../constant.dart';
import '../firestore_resouce/instances.dart';

Map<String, dynamic> kDefaultUserInfo(firebaseId) => {
      "username": "anonymous",
      "displayName": "Anonymous",
      "firebaseId": firebaseId,
      "isPro": 0,
      "thumbnail": "/thumbnails/default/user.jpg",
      "uniqueId": "Uanonymous",
      "isAnonymously": 1,
    };

int getTimestamp(data) => data[kDbTIMESTAMP];

String getContent(key, data) => ChatHelper.decrypt(key, data[kDbCONTENT]);

bool getIsMe(data) => data[kDbFROM] == loggedFirebaseId;

bool get isLogged => appPrefs.loginUser != null;

bool get isLoggedAnonymous => appPrefs.loginUser?.id == null;

String get loggedUsername => appPrefs.loginUser?.username ?? '';

String get loggedFirebaseId => appPrefs.loginUser?.firebaseId ?? '';

Future<bool> checkUserInfoFromFirestore(String? firebaseId) async {
  return (firebaseId != null &&
      firebaseId != "" &&
      (await colUSERS.doc(firebaseId).get()).exists);
}

Future<Map<String, dynamic>> getUserInfoFromFirestore(
    String? firebaseId) async {
  if (firebaseId != null &&
      firebaseId != "" &&
      (await colUSERS.doc(firebaseId).get()).exists) {
    return (await colUSERS.doc(firebaseId).get()).data() ??
        kDefaultUserInfo(firebaseId);
  }
  return kDefaultUserInfo(firebaseId);
}

Future<Map> getStatisticFirstMessage(int platformId) async {
  QuerySnapshot q = await colCONVERSATIONS
      .where(kDbMEMBERSFIREBASEID, arrayContains: loggedFirebaseId)
      .orderBy(kDbLASTMESSAGETIME, descending: true)
      .get();
  var totalfirstMessage = 0;
  var totalfirstMessageAnswer = 0;
  var totalfirstMessageAnswerTime = 0;
  for (var d in q.docs) {
    Map docData = d.data() as Map;
    if (docData['firstMessage'] != null &&
        docData['firstMessage'][kDbPLATFORMID] == platformId) {
      totalfirstMessage++;

      if (docData['firstMessageAnswer'] != null &&
          docData['firstMessageAnswer'][kDbFROM] == loggedFirebaseId) {
        if ((docData['firstMessageAnswer'][kDbTIMESTAMP] as int) >
            (docData['firstMessage'][kDbTIMESTAMP] as int)) {
          totalfirstMessageAnswerTime +=
              (docData['firstMessageAnswer'][kDbTIMESTAMP] as int) -
                  (docData['firstMessage'][kDbTIMESTAMP] as int);
        }
        totalfirstMessageAnswer++;
      }
    }
  }
  var result = {
    //in miliseconds
    "averageTimeResponse": totalfirstMessageAnswer == 0
        ? 0
        : totalfirstMessageAnswerTime / totalfirstMessageAnswer,
    "totalfirstMessage": totalfirstMessage,
    "pourcentageMessageResponse": totalfirstMessage == 0
        ? 0
        : ((totalfirstMessageAnswer / totalfirstMessage) * 100)
  };
  return result;
}

==> _private_chat-1.3.61.tar.gz: lib/utils/utils.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../chat_detail/chat_helper.dart';
import '../constant.dart';
import '../firestore_resouce/instances.dart';

Map<String, dynamic> kDefaultUserInfo(firebaseId) => {
      "username": "anonymous",
      "displayName": "Anonymous",
      "firebaseId": firebaseId,
      "isPro": 0,
      "thumbnail": "/thumbnails/default/user.jpg",
      "uniqueId": "Uanonymous",
      "isAnonymously": 1,
    };

int getTimestamp(data) => data[kDbTIMESTAMP];

String getContent(key, data) => ChatHelper.decrypt(key, data[kDbCONTENT]);

bool getIsMe(data) => data[kDbFROM] == loggedFirebaseId;

bool get isLogged => appPrefs.loginUser != null;

bool get isLoggedAnonymous => appPrefs.loginUser?.id == null;

String get loggedUsername => appPrefs.loginUser?.username ?? '';

String get loggedFirebaseId => appPrefs.loginUser?.firebaseId ?? '';

Future<bool> checkUserInfoFromFirestore(String? firebaseId) async {
  return (firebaseId != null &&
      firebaseId != "" &&
      (await colUSERS.doc(firebaseId).get()).exists);
}

Future<Map<String, dynamic>> getUserInfoFromFirestore(
    String? firebaseId) async {
  if (firebaseId != null &&
      firebaseId != "" &&
      (await colUSERS.doc(firebaseId).get()).exists) {
    return (await colUSERS.doc(firebaseId).get()).data() ??
        kDefaultUserInfo(firebaseId);
  }
  return kDefaultUserInfo(firebaseId);
}

Future<Map> getStatisticFirstMessage(int platformId) async {
  QuerySnapshot q = await colCONVERSATIONS
      .where(kDbMEMBERSFIREBASEID, arrayContains: loggedFirebaseId)
      .orderBy(kDbLASTMESSAGETIME, descending: true)
      .get();
  var totalfirstMessage = 0;
  var totalfirstMessageAnswer = 0;
  var totalfirstMessageAnswerTime = 0;
  for (var d in q.docs) {
    Map docData = d.data() as Map;
    if (docData['firstMessage'] != null &&
        docData['firstMessage'][kDbPLATFORMID] == platformId &&
        docData['firstMessage'][kDbFROM] != loggedFirebaseId) {
      totalfirstMessage++;

      if (docData['firstMessageAnswer'] != null &&
          docData['firstMessageAnswer'][kDbFROM] == loggedFirebaseId) {
        if ((docData['firstMessageAnswer'][kDbTIMESTAMP] as int) >
            (docData['firstMessage'][kDbTIMESTAMP] as int)) {
          totalfirstMessageAnswerTime +=
              (docData['firstMessageAnswer'][kDbTIMESTAMP] as int) -
                  (docData['firstMessage'][kDbTIMESTAMP] as int);
        }
        totalfirstMessageAnswer++;
      }
    }
  }
  var result = {
    //in miliseconds
    "averageTimeResponse": totalfirstMessageAnswer == 0
        ? 0
        : totalfirstMessageAnswerTime / totalfirstMessageAnswer,
    "totalfirstMessage": totalfirstMessage,
    "pourcentageMessageResponse": totalfirstMessage == 0
        ? 0
        : ((totalfirstMessageAnswer / totalfirstMessage) * 100)
  };
  return result;
}
